<?php

/**
 * Enhancements to recent posts
 *
 * @package RecentPostsEnhancement
 * @version 2.0.9
 * @author davidhs
 * @copyright 2013-2019 by davidhs
 * @license Creative Commons Attribution 3.0 Unported License https://creativecommons.org/licenses/by/3.0/
 */

if (!defined('SMF'))
	die('Hacking attempt...');

// Adds admin area.
function rpe_admin_areas(&$admin_areas)
{
	global $txt;

	$admin_areas['config']['areas']['modsettings']['subsections']['rpe'] = array($txt['rpe']);
}

// Adds admin search.
function rpe_admin_search(&$language_files, &$include_files, &$settings_search)
{
	$settings_search[] = array('rpeSettings', 'area=modsettings;sa=rpe');
}

// Adds modify modification.
function rpe_modify_modifications(&$subActions)
{
	global $context, $txt;

	$subActions['rpe'] = 'rpeSettings';

	$context[$context['admin_menu_name']]['tab_data']['tabs']['rpe'] = array(
		'label' => $txt['rpe'],
		'description' => $txt['rpe_desc'],
	);
}

// Admin area settings.
function rpeSettings($return_config = false)
{
	global $txt, $scripturl, $context;

	$config_vars = array();
	$config_vars[] = array('title', 'rpe');
	$config_vars[] = array('check', 'rpe_hide_unread_new');
	$config_vars[] = array('check', 'rpe_hide_unread_all');
	$config_vars[] = array('check', 'rpe_hide_unread_replies');
	$config_vars[] = array('check', 'rpe_hide_recent');
	$config_vars[] = array('check', 'rpe_one_line');
	$config_vars[] = '';
	$config_vars[] = array('check', 'rpe_menu_hide_unread_new');
	$config_vars[] = array('check', 'rpe_menu_hide_unread_all');
	$config_vars[] = array('check', 'rpe_menu_hide_unread_replies');
	$config_vars[] = array('check', 'rpe_menu_hide_recent');
	$config_vars[] = array('check', 'rpe_menu_one_button');
	$config_vars[] = '';
	$config_vars[] = array('check', 'rpe_category_hide_unread_new');
	$config_vars[] = array('check', 'rpe_category_hide_unread_all');
	$config_vars[] = array('check', 'rpe_category_hide_unread_replies');
	$config_vars[] = array('check', 'rpe_category_hide_recent');
	$config_vars[] = array('check', 'rpe_category_one_line');
	foreach ($config_vars as $i => $v)
	{
		if (is_array($v) && 'check' == $v[0])
		{
			$format = '';
			if (0 === strpos($v[1], 'rpe_hide'))
				$format = $txt['rpe_hide'];
			elseif (0 === strpos($v[1], 'rpe_menu_hide'))
				$format = $txt['rpe_menu_hide'];
			elseif (0 === strpos($v[1], 'rpe_category_hide'))
				$format = $txt['rpe_category_hide'];

			if (!empty($format))
			{
				if (strpos($v[1], 'unread_new'))
					$arg = $txt['unread_topics_visit'];
				elseif (strpos($v[1], 'unread_all'))
					$arg = $txt['unread_topics_all'];
				elseif (strpos($v[1], 'unread_replies'))
					$arg = $txt['unread_replies'];
				else // strpos($v[1], 'recent')
					$arg = $txt['recent_posts'];

				$config_vars[$i]['text_label'] = sprintf($format, $arg);
			}
		}
	}

	if ($return_config)
		return $config_vars;

	$context['post_url'] = $scripturl . '?action=admin;area=modsettings;save;sa=rpe';

	// No removing this line you, dirty unwashed mod authors. :p
	if (empty($config_vars))
	{
		$context['settings_save_dont_show'] = true;
		$context['settings_message'] = '<div class="centertext">' . $txt['modification_no_misc_settings'] . '</div>';

		return prepareDBSettingContext($config_vars);
	}

	// Saving?
	if (isset($_GET['save']))
	{
		checkSession();
		$save_vars = $config_vars;
		saveDBSettings($save_vars);
		logActions(array(array(
			'action' => 'rpe_edit',
			'log_type' => 'admin',
			'extra' => array(
			),
		)));
		$_SESSION['adm-save'] = true;
		redirectexit('action=admin;area=modsettings;sa=rpe');
	}

	prepareDBSettingContext($config_vars);
}

?>