<?php

/**
 * Enhancements to recent posts
 *
 * @package RecentPostsEnhancement
 * @version 2.0.8
 * @author davidhs
 * @copyright 2013-2019 by davidhs
 * @license Creative Commons Attribution 3.0 Unported License https://creativecommons.org/licenses/by/3.0/
 */

if (!defined('SMF'))
	die('Hacking attempt...');

// Adds unread posts menu.
function rpe_menu_buttons(&$buttons)
{
	global $context, $txt, $scripturl, $modSettings;

	$rpe_links = rpeLinks('menu');
	if (!empty($rpe_links))
	{
		$buttons2 = $buttons;
		$buttons = array();
		foreach ($buttons2 as $i => $b)
		{
			$buttons[$i] = $b;
			if ('moderate' == $i)
			{
				if (empty($modSettings['rpe_menu_one_button']))
				{
					foreach ($rpe_links as $rpe_link)
					{
						$buttons[$rpe_link[0]] = array(
							'icon' => 'post/xx.png',
							'title' => $rpe_link[1],
							'href' => $rpe_link[2],
							'show' => true,
							'sub_buttons' => array(
							),
						);
					}
				}
				else
				{
					$sub_buttons = array();
					foreach ($rpe_links as $rpe_link)
					{
						$sub_buttons[$rpe_link[0]] = array(
							'title' => $rpe_link[1],
							'href' => $rpe_link[2],
							'show' => true,
						);
					}

					end($sub_buttons);
					$sub_buttons[key($sub_buttons)]['is_last'] = true;

					$rpe_link = $rpe_links[0];
					$buttons['rpe'] = array(
						'icon' => 'post/xx.png',
						'title' => $txt['posts'],
						'href' => $rpe_link[2],
						'show' => true,
						'sub_buttons' => $sub_buttons,
					);
				}
			}
		}
	}
}

// Returns links to unread posts.
function rpeLinks($location = '', $c = '')
{
	global $txt, $scripturl, $user_info, $modSettings;

	$rpe_links = array();

	if ('menu' == $location)
	{
		if (empty($modSettings['rpe_menu_one_button']))
		{
			$unread_new = 'unread_topics_visit';
			$unread_all = 'unread_topics_all';
			$unread_replies = 'unread_replies';
			$recent = 'recent_posts';
		}
		else
		{
			$unread_new = 'rpe_unread_new';
			$unread_all = 'rpe_unread_all';
			$unread_replies = 'rpe_unread_replies';
			$recent = 'rpe_recent';
		}

		if (!$user_info['is_guest'] && empty($modSettings['rpe_menu_hide_unread_new']))
		{
			$rpe_links[] = array(
				'unread',
				$txt[$unread_new],
				$scripturl . '?action=unread',
			);
		}
		if (!$user_info['is_guest'] && empty($modSettings['rpe_menu_hide_unread_all']))
		{
			$rpe_links[] = array(
				'unread_all',
				$txt[$unread_all],
				$scripturl . '?action=unread;all;start=0',
			);
		}
		if (!$user_info['is_guest'] && empty($modSettings['rpe_menu_hide_unread_replies']))
		{
			$rpe_links[] = array(
				'unreadreplies',
				$txt[$unread_replies],
				$scripturl . '?action=unreadreplies',
			);
		}
		if ((!empty($modSettings['allow_guestAccess']) || !$user_info['is_guest']) && empty($modSettings['rpe_menu_hide_recent']))
		{
			$rpe_links[] = array(
				'recent',
				$txt[$recent],
				$scripturl . '?action=recent',
			);
		}
	}
	else
	{
		if ('category' == $location)
		{
			$location_var = '_category';
			$c_var = ';c=' . $c;
			if (empty($modSettings['rpe_category_one_line']))
			{
				$unread_new = 'unread_topics_visit';
				$unread_all = 'unread_topics_all';
				$unread_replies = 'unread_replies';
				$recent = 'recent_posts';
			}
		}
		else // header
		{
			$location_var = '';
			$c_var = '';
			if (empty($modSettings['rpe_one_line']))
			{
				$unread_new = 'unread_topics_visit';
				$unread_all = 'unread_topics_all';
				$unread_replies = 'unread_replies';
				$recent = 'recent_posts';
			}
		}

		if (empty($modSettings['rpe' . $location_var . '_one_line']))
		{
			if (!$user_info['is_guest'] && empty($modSettings['rpe' . $location_var . '_hide_unread_new']))
				$rpe_links[] = '<a href="' . $scripturl . '?action=unread' . $c_var . '">' . $txt[$unread_new] . '</a>';
			if (!$user_info['is_guest'] && empty($modSettings['rpe' . $location_var . '_hide_unread_all']))
				$rpe_links[] = '<a href="' . $scripturl . '?action=unread;all' . $c_var . ';start=0">' . $txt[$unread_all] . '</a>';
			if (!$user_info['is_guest'] && empty($modSettings['rpe' . $location_var . '_hide_unread_replies']))
				$rpe_links[] = '<a href="' . $scripturl . '?action=unreadreplies' . $c_var . '">' . $txt[$unread_replies] . '</a>';
			if ((!empty($modSettings['allow_guestAccess']) || !$user_info['is_guest']) && empty($modSettings['rpe' . $location_var . '_hide_recent']))
				$rpe_links[] = '<a href="' . $scripturl . '?action=recent' . $c_var . '">' . $txt[$recent] . '</a>';
		}
		else
		{
			if (!$user_info['is_guest'] && empty($modSettings['rpe' . $location_var . '_hide_unread_new']))
				$rpe_links[] = '<a href="' . $scripturl . '?action=unread' . $c_var . '">' . $txt['rpe_unread_new'] . '</a>';
			if (!$user_info['is_guest'] && empty($modSettings['rpe' . $location_var . '_hide_unread_all']))
				$rpe_links[] = '<a href="' . $scripturl . '?action=unread;all' . $c_var . ';start=0">' . $txt['rpe_unread_all'] . '</a>';
			if (!$user_info['is_guest'] && empty($modSettings['rpe' . $location_var . '_hide_unread_replies']))
				$rpe_links[] = '<a href="' . $scripturl . '?action=unreadreplies' . $c_var . '">' . $txt['rpe_unread_replies'] . '</a>';
			if ((!empty($modSettings['allow_guestAccess']) || !$user_info['is_guest']) && empty($modSettings['rpe' . $location_var . '_hide_recent']))
				$rpe_links[] = '<a href="' . $scripturl . '?action=recent' . $c_var . '">' . $txt['rpe_recent'] . '</a>';
		}
	}

	return $rpe_links;
}

?>